@@ -160,8 +160,7 @@ class Postgres_Handler:
         # table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query = sql.SQL(
-            'INSERT INTO {table_name} ({columns}) VALUES({values})'.format(
+        query = sql.SQL('INSERT INTO {table_name} ({columns}) VALUES({values})').format(
                 columns = sql.SQL(', ').join(
                     map(sql.Identifier, kwargs.keys())
                 ),
@@ -170,7 +169,7 @@ class Postgres_Handler:
                 ),
                 table_name =sql.Identifier(kwargs[self.table_name_key])
             )
-        )
+        
     
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
@@ -191,9 +190,15 @@ class Postgres_Handler:
         
     def __format_results(self, results):
         internal_status = results[0]
-        message = results[1]  if internal_status != -1 else ''
-        error = results[1] if internal_status == -1  else ''
-        status_code = 200 if internal_status != -1 else 400
+        if internal_status == -1:
+            print(results[1])
+            error = results[1]
+            message = ''
+            status_code = 400
+        else:
+            error = ''
+            message = results[1]
+            status_code = 200
                 
         return {
             'statusCode': status_code,
